pub fn x11_get_server_time(window: &X11Window) -> u32Expand description
Routine to get the current X server time stamp.
window
a gdk::Window, used for communication
with the server. The window must have
GDK_PROPERTY_CHANGE_MASK in its events mask or a hang will
result.
Returns
the time stamp.