x11_get_xatom_by_name

Function x11_get_xatom_by_name 

pub fn x11_get_xatom_by_name(atom_name: &str) -> Atom
Returns the X atom for GDK’s default display corresponding to atom_name. This function caches the result, so if called repeatedly it is much faster than XInternAtom(), which is a round trip to the server each time.

atom_name

a string

Returns

a X atom for GDK’s default display.