pub struct X11DeviceXI2 { /* private fields */ }Expand description
Properties
device-id
Readable | Writable | Construct Only
Device
associated-device
Associated pointer or keyboard with this device, if any. Devices of type gdk::DeviceType::Master
always come in keyboard/pointer pairs. Other device types will have a None associated device.
Readable
axes
The axes currently available for this device.
Readable
device-manager
The gdk::DeviceManager the gdk::Device pertains to.
Readable | Writable | Construct Only
display
The gdk::Display the gdk::Device pertains to.
Readable | Writable | Construct Only
has-cursor
Whether the device is represented by a cursor on the screen. Devices of type
gdk::DeviceType::Master will have true here.
Readable | Writable | Construct Only
input-mode
Readable | Writable
input-source
Source type for the device.
Readable | Writable | Construct Only
n-axes
Number of axes in the device.
Readable
name
The device name.
Readable | Writable | Construct Only
num-touches
The maximal number of concurrent touches on a touch device. Will be 0 if the device is not a touch device or if the number of touches is unknown.
Readable | Writable | Construct Only
product-id
Product ID of this device, see [DeviceExtManual::product_id()][crate::gdk::prelude::DeviceExtManual::product_id()].
Readable | Writable | Construct Only
seat
gdk::Seat of this device.
Readable | Writable
tool
Readable
type
Device role in the device manager.
Readable | Writable | Construct Only
vendor-id
Vendor ID of this device, see [DeviceExtManual::vendor_id()][crate::gdk::prelude::DeviceExtManual::vendor_id()].
Readable | Writable | Construct Only
Implements
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl X11DeviceXI2
impl X11DeviceXI2
Sourcepub fn builder() -> X11DeviceXI2Builder
pub fn builder() -> X11DeviceXI2Builder
Creates a new builder-pattern struct instance to construct X11DeviceXI2 objects.
This method returns an instance of X11DeviceXI2Builder which can be used to create X11DeviceXI2 objects.
pub fn device_id(&self) -> i32