X11Display

Struct X11Display 

pub struct X11Display { /* private fields */ }
Implements

[trait@gdk::prelude::DisplayExt]

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl X11Display

pub fn error_trap_pop(&self) -> i32

Pops the error trap pushed by error_trap_push(). Will XSync() if necessary and will always block until the error is known to have occurred or not occurred, so the error code can be returned.

If you don’t need to use the return value, error_trap_pop_ignored() would be more efficient.

See gdk_error_trap_pop() for the all-displays-at-once equivalent.

Returns

X error code or 0 on success

pub fn error_trap_pop_ignored(&self)

Pops the error trap pushed by error_trap_push(). Does not block to see if an error occurred; merely records the range of requests to ignore errors for, and ignores those errors if they arrive asynchronously.

See gdk_error_trap_pop_ignored() for the all-displays-at-once equivalent.

pub fn error_trap_push(&self)

Begins a range of X requests on self for which X error events will be ignored. Unignored errors (when no trap is pushed) will abort the application. Use error_trap_pop() or error_trap_pop_ignored()to lift a trap pushed with this function.

See also gdk_error_trap_push() to push a trap on all displays.

pub fn startup_notification_id(&self) -> Option<GString>

Gets the startup notification ID for a display.

Returns

the startup notification ID for self

pub fn user_time(&self) -> u32

Returns the timestamp of the last user interaction on self. The timestamp is taken from events caused by user interaction such as key presses or pointer movements. See X11Window::set_user_time().

Returns

the timestamp of the last user interaction

pub fn grab(&self)

Call XGrabServer() on self. To ungrab the display again, use ungrab().

grab()/ungrab() calls can be nested.

pub fn set_cursor_theme(&self, theme: Option<&str>, size: i32)

Sets the cursor theme from which the images for cursor should be taken.

If the windowing system supports it, existing cursors created with gdk_cursor_new(), gdk::Cursor::for_display() and gdk::Cursor::from_name() are updated to reflect the theme change. Custom cursors constructed with gdk::Cursor::from_pixbuf() will have to be handled by the application (GTK+ applications can learn about cursor theme changes by listening for change notification for the corresponding GtkSetting).

theme

the name of the cursor theme to use, or None to unset a previously set value

size

the cursor size to use, or 0 to keep the previous size

pub fn set_startup_notification_id(&self, startup_id: &str)

Sets the startup notification ID for a display.

This is usually taken from the value of the DESKTOP_STARTUP_ID environment variable, but in some cases (such as the application not being launched using exec()) it can come from other sources.

If the ID contains the string “_TIME” then the portion following that string is taken to be the X11 timestamp of the event that triggered the application to be launched and the GDK current event time is set accordingly.

The startup ID is also what is used to signal that the startup is complete (for example, when opening a window or when calling gdk_notify_startup_complete()).

startup_id

the startup notification ID (must be valid utf8)

pub fn set_window_scale(&self, scale: i32)

Forces a specific window scale for all windows on this display, instead of using the default or user configured scale. This is can be used to disable scaling support by setting scale to 1, or to programmatically set the window scale.

Once the scale is set by this call it will not change in response to later user configuration changes.

scale

The new scale value

pub fn string_to_compound_text(&self, str: &str) -> (i32, Atom, i32, Vec<u8>)

Convert a string from the encoding of the current locale into a form suitable for storing in a window property.

str

a nul-terminated string

Returns

0 upon success, non-zero upon failure

encoding

location to store the encoding atom (to be used as the type for the property)

format

location to store the format of the property

ctext

location to store newly allocated data for the property

pub fn ungrab(&self)

Ungrab self after it has been grabbed with grab().

pub fn utf8_to_compound_text(&self, str: &str) -> Option<(Atom, i32, Vec<u8>)>

Converts from UTF-8 to compound text.

str

a UTF-8 string

Returns

true if the conversion succeeded, otherwise false

encoding

location to store resulting encoding

format

location to store format of the result

ctext

location to store the data of the result

pub fn glx_version(display: &impl IsA<Display>) -> Option<(i32, i32)>

Retrieves the version of the GLX implementation.

display

a gdk::Display

Returns

true if GLX is available

major

return location for the GLX major version

minor

return location for the GLX minor version

Source

impl X11Display

pub unsafe fn xdisplay(&self) -> *mut Display

Returns the X display of a gdk::Display.

Returns

an X display