pub struct X11Screen { /* private fields */ }Expand description
Signals
window-manager-changed
Screen
composited-changed
The ::composited-changed signal is emitted when the composited status of the screen changes
monitors-changed
The ::monitors-changed signal is emitted when the number, size or position of the monitors attached to the screen change.
Only for X11 and OS X for now. A future implementation for Win32 may be a possibility.
size-changed
The ::size-changed signal is emitted when the pixel width or height of a screen changes.
Implements
[trait@gdk::prelude::ScreenExt]
Implementations
Sourceimpl X11Screen
impl X11Screen
Sourcepub fn current_desktop(&self) -> u32
pub fn current_desktop(&self) -> u32
Returns the current workspace for self when running under a
window manager that supports multiple workspaces, as described
in the
Extended Window Manager Hints specification.
Returns
the current workspace, or 0 if workspaces are not supported
Sourcepub fn monitor_output(&self, monitor_num: i32) -> XID
pub fn monitor_output(&self, monitor_num: i32) -> XID
Sourcepub fn number_of_desktops(&self) -> u32
pub fn number_of_desktops(&self) -> u32
Returns the number of workspaces for self when running under a
window manager that supports multiple workspaces, as described
in the
Extended Window Manager Hints specification.
Returns
the number of workspaces, or 0 if workspaces are not supported
Sourcepub fn screen_number(&self) -> i32
pub fn screen_number(&self) -> i32
Sourcepub fn window_manager_name(&self) -> Option<GString>
pub fn window_manager_name(&self) -> Option<GString>
Returns the name of the window manager for self.
Returns
the name of the window manager screen self, or
“unknown” if the window manager is unknown. The string is owned by GDK
and should not be freed.
Sourcepub fn lookup_visual(&self, xvisualid: VisualID) -> Option<X11Visual>
pub fn lookup_visual(&self, xvisualid: VisualID) -> Option<X11Visual>
Looks up the gdk::Visual for a particular screen and X Visual ID.
xvisualid
an X Visual ID.
Returns
the gdk::Visual (owned by the screen
object), or None if the visual ID wasn’t found.
Sourcepub fn supports_net_wm_hint(&self, property: &Atom) -> bool
pub fn supports_net_wm_hint(&self, property: &Atom) -> bool
This function is specific to the X11 backend of GDK, and indicates whether the window manager supports a certain hint from the Extended Window Manager Hints specification.
When using this function, keep in mind that the window manager
can change over time; so you shouldn’t use this function in
a way that impacts persistent application state. A common bug
is that your application can start up before the window manager
does when the user logs in, and before the window manager starts
supports_net_wm_hint() will return false for every property.
You can monitor the window_manager_changed signal on gdk::Screen to detect
a window manager change.
property
a property atom.
Returns
true if the window manager supports property
pub fn connect_window_manager_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId